@@ -3,7 +3,6 @@
 Contains functions for the `Eyring equation
 <https://en.wikipedia.org/wiki/Eyring_equation>`_.
 """
-from __future__ import (absolute_import, division, print_function)
 
 import math
 
@@ -25,10 +24,9 @@ def _get_kB_over_h(constants=None, units=None):
         if units is not None:
             s = units.second
             K = units.kelvin
-            kB_over_h /= s*K
+            kB_over_h /= s * K
     else:
-        kB_over_h = (constants.Boltzmann_constant /
-                     constants.Planck_constant)
+        kB_over_h = constants.Boltzmann_constant / constants.Planck_constant
     return kB_over_h
 
 
@@ -61,20 +59,20 @@ def eyring_equation(dH, dS, T, constants=None, units=None, backend=None):
     kB_over_h = _get_kB_over_h(constants, units)
 
     try:
-        RT = (R*T).rescale(dH.dimensionality)
+        RT = (R * T).rescale(dH.dimensionality)
     except AttributeError:
-        RT = R*T
+        RT = R * T
 
     try:
         kB_over_h = kB_over_h.simplified
     except AttributeError:
         pass
 
-    return kB_over_h*T*be.exp(dS/R)*be.exp(-dH/RT)
+    return kB_over_h * T * be.exp(dS / R) * be.exp(-dH / RT)
 
 
 def fit_eyring_equation(T, k, kerr=None, linearized=False, constants=None, units=None):
-    """ Curve fitting of the Eyring equation to data points
+    """Curve fitting of the Eyring equation to data points
 
     Parameters
     ----------
@@ -86,12 +84,20 @@ def fit_eyring_equation(T, k, kerr=None, linearized=False, constants=None, units
     """
     R = _get_R(constants, units)
     ln_kb_over_h = math.log(_get_kB_over_h(constants, units))
-    return _fit(T, k, kerr, eyring_equation, lambda T, k: 1/T, lambda T, k: np.log(k/T),
-                [lambda p: -p[1]*R, lambda p: R*(p[0] - ln_kb_over_h)], linearized=linearized)
+    return _fit(
+        T,
+        k,
+        kerr,
+        eyring_equation,
+        lambda T, k: 1 / T,
+        lambda T, k: np.log(k / T),
+        [lambda p: -p[1] * R, lambda p: R * (p[0] - ln_kb_over_h)],
+        linearized=linearized,
+    )
 
 
-class EyringParam(defaultnamedtuple('EyringParam', 'dH dS ref', [None])):
-    """ Kinetic data in the form of an Eyring parameterisation
+class EyringParam(defaultnamedtuple("EyringParam", "dH dS ref", [None])):
+    """Kinetic data in the form of an Eyring parameterisation
 
     Parameters
     ----------
@@ -111,7 +117,7 @@ class EyringParam(defaultnamedtuple('EyringParam', 'dH dS ref', [None])):
     """
 
     def __call__(self, T, constants=None, units=None, backend=None):
-        """ Evaluates the Eyring equation for a specified state
+        """Evaluates the Eyring equation for a specified state
 
         Parameters
         ----------
@@ -125,22 +131,26 @@ class EyringParam(defaultnamedtuple('EyringParam', 'dH dS ref', [None])):
         chempy.eyring.eyring_equation : the function used here
 
         """
-        return eyring_equation(self.dH, self.dS, T, constants=constants,
-                               units=units, backend=backend)
+        return eyring_equation(
+            self.dH, self.dS, T, constants=constants, units=units, backend=backend
+        )
 
     def kB_h_times_exp_dS_R(self, constants=None, units=None, backend=math):
         R = _get_R(constants, units)
         kB_over_h = _get_kB_over_h(constants, units)
-        return kB_over_h * backend.exp(self.dS/R)
+        return kB_over_h * backend.exp(self.dS / R)
 
     def dH_over_R(self, constants=None, units=None, backend=None):
         R = _get_R(constants, units)
-        return self.dH/R
+        return self.dH / R
 
     def as_RateExpr(self, unique_keys=None, constants=None, units=None, backend=math):
         from .rates import Eyring, MassAction
-        args = [self.kB_h_times_exp_dS_R(constants, units, backend),
-                self.dH_over_R(constants, units)]
+
+        args = [
+            self.kB_h_times_exp_dS_R(constants, units, backend),
+            self.dH_over_R(constants, units),
+        ]
         return MassAction(Eyring(args, unique_keys))
 
     def format(self, precision, tex=False):
@@ -148,8 +158,8 @@ class EyringParam(defaultnamedtuple('EyringParam', 'dH dS ref', [None])):
             str_A, str_A_unit = format_string(self.A, precision, tex)
             str_Ea, str_Ea_unit = format_string(self.Ea, precision, tex)
         except Exception:
-            str_A, str_A_unit = precision.format(self.A), '-'
-            str_Ea, str_Ea_unit = precision.format(self.Ea), '-'
+            str_A, str_A_unit = precision.format(self.A), "-"
+            str_Ea, str_Ea_unit = precision.format(self.Ea), "-"
         return (str_A, str_A_unit), (str_Ea, str_Ea_unit)
 
     def equation_as_string(self, precision, tex=False):
@@ -157,28 +167,40 @@ class EyringParam(defaultnamedtuple('EyringParam', 'dH dS ref', [None])):
         if tex:
             return (
                 r"\frac{{k_B T}}{{h}}\exp \left(\frac{{{}}}{{R}} \right)"
-                r" \exp \left(-\frac{{{}}}{{RT}} \right)").format(
-                    str_A, str_Ea + ' ' + str_Ea_unit), str_A_unit
+                r" \exp \left(-\frac{{{}}}{{RT}} \right)"
+            ).format(str_A, str_Ea + " " + str_Ea_unit), str_A_unit
         else:
-            return "kB*T/h*exp({}/R)*exp(-{}/(R*T))".format(
-                str_A, str_Ea + ' ' + str_Ea_unit), str_A_unit
+            return (
+                "kB*T/h*exp({}/R)*exp(-{}/(R*T))".format(
+                    str_A, str_Ea + " " + str_Ea_unit
+                ),
+                str_A_unit,
+            )
 
     def __str__(self):
-        return self.equation_as_string('%.5g')
+        return self.equation_as_string("%.5g")
 
 
 class EyringParamWithUnits(EyringParam):
-    def __call__(self, state, constants=default_constants, units=default_units,
-                 backend=None):
-        """ See :func:`chempy.eyring.eyring_equation`. """
+    def __call__(
+        self, state, constants=default_constants, units=default_units, backend=None
+    ):
+        """See :func:`chempy.eyring.eyring_equation`."""
         if backend is None:
             backend = Backend()
         return super(EyringParamWithUnits, self).__call__(
-            state, constants, units, backend)
+            state, constants, units, backend
+        )
 
-    def as_RateExpr(self, unique_keys=None, constants=default_constants,
-                    units=default_units, backend=None):
+    def as_RateExpr(
+        self,
+        unique_keys=None,
+        constants=default_constants,
+        units=default_units,
+        backend=None,
+    ):
         if backend is None:
             backend = Backend()
         return super(EyringParamWithUnits, self).as_RateExpr(
-            unique_keys, constants, units, backend)
+            unique_keys, constants, units, backend
+        )
