@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function)
 
 from math import log10, floor
 
@@ -17,13 +16,13 @@ def roman(num):
     'XVII'
 
     """
-    tokens = 'M CM D CD C XC L XL X IX V IV I'.split()
+    tokens = "M CM D CD C XC L XL X IX V IV I".split()
     values = 1000, 900, 500, 400, 100, 90, 50, 40, 10, 9, 5, 4, 1
-    result = ''
+    result = ""
     for t, v in zip(tokens, values):
-        cnt = num//v
-        result += t*cnt
-        num -= v*cnt
+        cnt = num // v
+        result += t * cnt
+        num -= v * cnt
     return result
 
 
@@ -32,7 +31,7 @@ def _mag(num):
 
 
 def _float_str_w_uncert(x, xe, precision=2):
-    """ Prints uncertain number with parenthesis
+    """Prints uncertain number with parenthesis
 
     Parameters
     ----------
@@ -71,22 +70,22 @@ def _float_str_w_uncert(x, xe, precision=2):
     xe_exp = int(floor(log10(abs(xe))))
 
     # uncertainty
-    un_exp = xe_exp-precision+1
-    un_int = round(xe*10**(-un_exp))
+    un_exp = xe_exp - precision + 1
+    un_int = round(xe * 10 ** (-un_exp))
 
     # nominal value
     no_exp = un_exp
-    no_int = round(x*10**(-no_exp))
+    no_int = round(x * 10 ** (-no_exp))
 
     # format - nom(unc)exp
     fieldw = x_exp - no_exp
-    fmt = '%%.%df' % fieldw
-    result1 = (fmt + '(%.0f)e%d') % (no_int*10**(-fieldw), un_int, x_exp)
+    fmt = "%%.%df" % fieldw
+    result1 = (fmt + "(%.0f)e%d") % (no_int * 10 ** (-fieldw), un_int, x_exp)
 
     # format - nom(unc)
     fieldw = max(0, -no_exp)
-    fmt = '%%.%df' % fieldw
-    result2 = (fmt + '(%.0f)') % (no_int*10**no_exp, un_int*10**max(0, un_exp))
+    fmt = "%%.%df" % fieldw
+    result2 = (fmt + "(%.0f)") % (no_int * 10 ** no_exp, un_int * 10 ** max(0, un_exp))
 
     # return shortest representation
     if len(result2) <= len(result1):
@@ -95,12 +94,12 @@ def _float_str_w_uncert(x, xe, precision=2):
         return result1
 
 
-def _number_to_X(number, uncertainty, unit, fmt, unit_fmt, fmt_pow_10, space=' '):
-    uncertainty = uncertainty or getattr(number, 'uncertainty', None)
+def _number_to_X(number, uncertainty, unit, fmt, unit_fmt, fmt_pow_10, space=" "):
+    uncertainty = uncertainty or getattr(number, "uncertainty", None)
     unit = unit or unit_of(number)
     integer_one = 1
     if unit is integer_one:
-        unit_str = ''
+        unit_str = ""
         mag = number
     else:
         unit_str = space + unit_fmt(unit)
@@ -112,7 +111,7 @@ def _number_to_X(number, uncertainty, unit, fmt, unit_fmt, fmt_pow_10, space=' '
         if fmt is None:
             fmt = 5
         if isinstance(fmt, int):
-            flt = ('%%.%dg' % fmt) % mag
+            flt = ("%%.%dg" % fmt) % mag
         else:
             flt = fmt(mag)
     else:
@@ -122,23 +121,23 @@ def _number_to_X(number, uncertainty, unit, fmt, unit_fmt, fmt_pow_10, space=' '
             flt = _float_str_w_uncert(mag, uncertainty, fmt)
         else:
             flt = fmt(mag, uncertainty)
-    if 'e' in flt:
-        significand, mantissa = flt.split('e')
+    if "e" in flt:
+        significand, mantissa = flt.split("e")
         return fmt_pow_10(significand, mantissa) + unit_str
     else:
         return flt + unit_str
 
 
 def _latex_pow_10(significand, mantissa):
-    if significand in ('1', '1.0'):
-        fmt = '10^{%s}'
+    if significand in ("1", "1.0"):
+        fmt = "10^{%s}"
     else:
-        fmt = significand + r'\cdot 10^{%s}'
+        fmt = significand + r"\cdot 10^{%s}"
     return fmt % str(int(mantissa))
 
 
 def number_to_scientific_latex(number, uncertainty=None, unit=None, fmt=None):
-    r""" Formats a number as LaTeX (optionally with unit/uncertainty)
+    r"""Formats a number as LaTeX (optionally with unit/uncertainty)
 
     Parameters
     ----------
@@ -160,19 +159,21 @@ def number_to_scientific_latex(number, uncertainty=None, unit=None, fmt=None):
     '1.23(79)'
 
     """
-    return _number_to_X(number, uncertainty, unit, fmt, latex_of_unit, _latex_pow_10, r'\,')
+    return _number_to_X(
+        number, uncertainty, unit, fmt, latex_of_unit, _latex_pow_10, r"\,"
+    )
 
 
 def _unicode_pow_10(significand, mantissa):
-    if significand in ('1', '1.0'):
-        result = u'10'
+    if significand in ("1", "1.0"):
+        result = u"10"
     else:
-        result = significand + u'·10'
-    return result + u''.join(map(_unicode_sup.get, str(int(mantissa))))
+        result = significand + u"·10"
+    return result + u"".join(map(_unicode_sup.get, str(int(mantissa))))
 
 
 def number_to_scientific_unicode(number, uncertainty=None, unit=None, fmt=None):
-    u""" Formats a number as unicode (optionally with unit/uncertainty)
+    u"""Formats a number as unicode (optionally with unit/uncertainty)
 
     Parameters
     ----------
@@ -192,19 +193,21 @@ def number_to_scientific_unicode(number, uncertainty=None, unit=None, fmt=None):
     '1.4142 m/s'
 
     """
-    return _number_to_X(number, uncertainty, unit, fmt, unicode_of_unit, _unicode_pow_10)
+    return _number_to_X(
+        number, uncertainty, unit, fmt, unicode_of_unit, _unicode_pow_10
+    )
 
 
 def _html_pow_10(significand, mantissa):
-    if significand in ('1', '1.0'):
-        result = '10<sup>'
+    if significand in ("1", "1.0"):
+        result = "10<sup>"
     else:
-        result = significand + '&sdot;10<sup>'
-    return result + str(int(mantissa)) + '</sup>'
+        result = significand + "&sdot;10<sup>"
+    return result + str(int(mantissa)) + "</sup>"
 
 
 def number_to_scientific_html(number, uncertainty=None, unit=None, fmt=None):
-    r""" Formats a number as HTML (optionally with unit/uncertainty)
+    r"""Formats a number as HTML (optionally with unit/uncertainty)
 
     Parameters
     ----------
