@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function)
 
 import math
 
@@ -12,7 +11,7 @@ from .util.pyutil import deprecated
 
 
 class ReactionSystem(object):
-    """ Collection of reactions forming a system (model).
+    """Collection of reactions forming a system (model).
 
     Parameters
     ----------
@@ -61,11 +60,19 @@ class ReactionSystem(object):
 
     _BaseReaction = Reaction
     _BaseSubstance = Substance
-    default_checks = {'balance', 'substance_keys', 'duplicate', 'duplicate_names'}
+    default_checks = {"balance", "substance_keys", "duplicate", "duplicate_names"}
 
-    def __init__(self, rxns, substances=None, name=None, checks=None, dont_check=None,
-                 substance_factory=Substance, missing_substances_from_keys=False,
-                 sort_substances=None):
+    def __init__(
+        self,
+        rxns,
+        substances=None,
+        name=None,
+        checks=None,
+        dont_check=None,
+        substance_factory=Substance,
+        missing_substances_from_keys=False,
+        sort_substances=None,
+    ):
         self.rxns = list(rxns)
         if substances is None:
             if self.rxns:
@@ -81,20 +88,27 @@ class ReactionSystem(object):
         if isinstance(substances, OrderedDict):
             self.substances = substances
         elif isinstance(substances, (str, set)):
-            if isinstance(substances, str) and ' ' in substances:
+            if isinstance(substances, str) and " " in substances:
                 substances = substances.split()
-            self.substances = OrderedDict([
-                (s, substance_factory(s)) for s in substances])
+            self.substances = OrderedDict(
+                [(s, substance_factory(s)) for s in substances]
+            )
         else:
             if all(isinstance(s, Substance) for s in substances):
                 self.substances = OrderedDict([(s.name, s) for s in substances])
-            elif hasattr(substances, 'values') and all(isinstance(s, Substance) for s in substances.values()):
+            elif hasattr(substances, "values") and all(
+                isinstance(s, Substance) for s in substances.values()
+            ):
                 self.substances = OrderedDict(substances)
             else:
-                self.substances = OrderedDict((k, substance_factory(k)) for k in substances)
+                self.substances = OrderedDict(
+                    (k, substance_factory(k)) for k in substances
+                )
 
         if missing_substances_from_keys:
-            for k in set.union(*[set(rxn.keys()) for rxn in self.rxns]) - set(self.substances):
+            for k in set.union(*[set(rxn.keys()) for rxn in self.rxns]) - set(
+                self.substances
+            ):
                 self.substances[k] = substance_factory(k)
 
         self.name = name
@@ -104,13 +118,13 @@ class ReactionSystem(object):
         if checks is None:
             checks = self.default_checks ^ (dont_check or set())
         for check in checks:
-            getattr(self, 'check_'+check)(throw=True)
+            getattr(self, "check_" + check)(throw=True)
 
         if sort_substances:
             self.sort_substances_inplace()
 
     def split(self, **kwargs):
-        """ Splits the reaction system into multiple disjoint reaction systems. """
+        """Splits the reaction system into multiple disjoint reaction systems."""
         groups = []  # tuples of (list, set) -- list of reactions, set of substance keys
         for i, r in enumerate(self.rxns):
             for gr, gs in groups:  # check if reaction is part of group, break out
@@ -129,7 +143,7 @@ class ReactionSystem(object):
         # We might have too many groups as this point, we will now recursively fuse groups
         i = 0
         while True:
-            for j in range(i+1, len(groups)):
+            for j in range(i + 1, len(groups)):
                 if groups[i][1] & groups[j][1]:  # do groups share a substance?
                     groups[i][0].extend(groups[j][0])
                     groups[i][1].update(groups[j][1])
@@ -139,14 +153,17 @@ class ReactionSystem(object):
                 i += 1
             if i >= len(groups):
                 break
-        return [self.__class__(
-            [self.rxns[ri] for ri in gr],
-            OrderedDict([(k, v) for k, v in self.substances.items() if k in gs]),
-            **kwargs
-        ) for gr, gs in groups]
+        return [
+            self.__class__(
+                [self.rxns[ri] for ri in gr],
+                OrderedDict([(k, v) for k, v in self.substances.items() if k in gs]),
+                **kwargs
+            )
+            for gr, gs in groups
+        ]
 
     def categorize_substances(self, **kwargs):
-        """ Returns categories of substance keys (e.g. nonparticipating, unaffected etc.)
+        """Returns categories of substance keys (e.g. nonparticipating, unaffected etc.)
 
         Some substances are only *accumulated* (i.e. irreversibly formed) and are never net
         reactants in any reactions, others are *depleted* (they are never net proucts in
@@ -169,6 +186,7 @@ class ReactionSystem(object):
 
         """
         import numpy as np
+
         irrev_rxns = []
         for r in self.rxns:
             try:
@@ -193,7 +211,9 @@ class ReactionSystem(object):
                 accumulated.add(sk)
             else:
                 if np.any(all_p[:, i] > 0):
-                    assert np.all(all_p[:, i] == all_r[:, i]), "Open issue at github.com/bjodah/chempy"
+                    assert np.all(
+                        all_p[:, i] == all_r[:, i]
+                    ), "Open issue at github.com/bjodah/chempy"
                     unaffected.add(sk)
                 else:
                     nonparticipating.add(sk)
@@ -201,25 +221,32 @@ class ReactionSystem(object):
             accumulated=accumulated,
             depleted=depleted,
             unaffected=unaffected,
-            nonparticipating=nonparticipating
+            nonparticipating=nonparticipating,
         )
 
     def sort_substances_inplace(self, key=lambda kv: kv[0]):
-        """ Sorts the OrderedDict attribute ``substances`` """
+        """Sorts the OrderedDict attribute ``substances``"""
         self.substances = OrderedDict(sorted(self.substances.items(), key=key))
 
     def _category_colors(self, checks=()):
         colors = {}
         categories = self.categorize_substances(checks=checks)
-        for k in categories['accumulated']:
-            colors[k] = ('90ee90', '008000')  # LightGreen, Green
-        for k in categories['depleted']:
-            colors[k] = ('ffb6c1', 'c71585')  # LightPink, MediumVioletRed
+        for k in categories["accumulated"]:
+            colors[k] = ("90ee90", "008000")  # LightGreen, Green
+        for k in categories["depleted"]:
+            colors[k] = ("ffb6c1", "c71585")  # LightPink, MediumVioletRed
         return colors
 
-    def html(self, with_param=True, with_name=True, checks=(), color_categories=True,
-             split=True, print_fn=None):
-        """ Returns a string with an HTML representation
+    def html(
+        self,
+        with_param=True,
+        with_name=True,
+        checks=(),
+        color_categories=True,
+        split=True,
+        print_fn=None,
+    ):
+        """Returns a string with an HTML representation
 
         Parameters
         ----------
@@ -238,27 +265,32 @@ class ReactionSystem(object):
         if split:
             parts = self.split(checks=checks)
             if len(parts) > 1:
-                return '<br><hl><br>'.join(rs.html(with_param=with_param, with_name=with_name)
-                                           for rs in parts)
+                return "<br><hl><br>".join(
+                    rs.html(with_param=with_param, with_name=with_name) for rs in parts
+                )
         colors = self._category_colors(checks=checks) if color_categories else {}
         return print_fn(self, colors=colors, substances=self.substances)
 
     def string(self, with_param=True, with_name=True):
         from .printing import str_
+
         return str_(self, with_param=with_param, with_name=with_name)
 
     def _repr_html_(self):  # jupyter notebook hook
         from .printing import javascript
+
         return self.html(print_fn=javascript)
 
     def check_duplicate(self, throw=False):
-        """ Raies ValueError if there are duplicates in ``self.rxns`` """
+        """Raies ValueError if there are duplicates in ``self.rxns``"""
         for i1, rxn1 in enumerate(self.rxns):
-            for i2, rxn2 in enumerate(self.rxns[i1+1:], i1+1):
+            for i2, rxn2 in enumerate(self.rxns[i1 + 1 :], i1 + 1):
                 if rxn1 == rxn2:
                     if throw:
-                        raise ValueError("Duplicate reactions %d & %d: %s" %
-                                         (i1, i2, rxn1.string(with_param=False, with_name=False)))
+                        raise ValueError(
+                            "Duplicate reactions %d & %d: %s"
+                            % (i1, i2, rxn1.string(with_param=False, with_name=False))
+                        )
                     else:
                         return False
         return True
@@ -279,8 +311,7 @@ class ReactionSystem(object):
 
     def check_substance_keys(self, throw=False):
         for rxn in self.rxns:
-            for key in chain(rxn.reac, rxn.prod, rxn.inact_reac,
-                             rxn.inact_prod):
+            for key in chain(rxn.reac, rxn.prod, rxn.inact_reac, rxn.inact_prod):
                 if key not in self.substances:
                     if throw:
                         raise ValueError("Unknown key: %s" % key)
@@ -289,7 +320,7 @@ class ReactionSystem(object):
         return True
 
     def check_balance(self, strict=False, throw=False):
-        """ Checks if all reactions are balanced.
+        """Checks if all reactions are balanced.
 
         Parameters
         ----------
@@ -309,33 +340,38 @@ class ReactionSystem(object):
                 else:
                     return True
         for rxn in self.rxns:
-            for net, k in zip(*rxn.composition_violation(self.substances, composition_keys=True)):
+            for net, k in zip(
+                *rxn.composition_violation(self.substances, composition_keys=True)
+            ):
                 if net != 0:
                     if throw:
-                        raise ValueError("Composition violation (%s: %s) in %s" %
-                                         (k, net, rxn.string(with_param=False, with_name=False)))
+                        raise ValueError(
+                            "Composition violation (%s: %s) in %s"
+                            % (k, net, rxn.string(with_param=False, with_name=False))
+                        )
                     else:
                         return False
         return True
 
     def obeys_mass_balance(self):
-        """ Returns True if all reactions obeys mass balance, else False. """
+        """Returns True if all reactions obeys mass balance, else False."""
         for rxn in self.rxns:
             if rxn.mass_balance_violation(self.substances) != 0:
                 return False
         return True
 
     def obeys_charge_neutrality(self):
-        """ Returns False if any reaction violate charge neutrality. """
+        """Returns False if any reaction violate charge neutrality."""
         for rxn in self.rxns:
             if rxn.charge_neutrality_violation(self.substances) != 0:
                 return False
         return True
 
     @classmethod
-    def from_string(cls, s, substances=None, rxn_parse_kwargs=None,
-                    comment_tokens=('#',), **kwargs):
-        """ Create a reaction system from a string
+    def from_string(
+        cls, s, substances=None, rxn_parse_kwargs=None, comment_tokens=("#",), **kwargs
+    ):
+        """Create a reaction system from a string
 
         Parameters
         ----------
@@ -359,12 +395,17 @@ class ReactionSystem(object):
         True
 
         """
-        substance_keys = None if kwargs.get('missing_substances_from_keys', False) else substances
-        rxns = [cls._BaseReaction.from_string(r, substance_keys, **(rxn_parse_kwargs or {}))
-                for r in s.split('\n') if r.strip() != '' and not any(
-                    r.strip().startswith(tok) for tok in comment_tokens)]
-        if 'substance_factory' not in kwargs:
-            kwargs['substance_factory'] = cls._BaseSubstance.from_formula
+        substance_keys = (
+            None if kwargs.get("missing_substances_from_keys", False) else substances
+        )
+        rxns = [
+            cls._BaseReaction.from_string(r, substance_keys, **(rxn_parse_kwargs or {}))
+            for r in s.split("\n")
+            if r.strip() != ""
+            and not any(r.strip().startswith(tok) for tok in comment_tokens)
+        ]
+        if "substance_factory" not in kwargs:
+            kwargs["substance_factory"] = cls._BaseSubstance.from_formula
         return cls(rxns, substances, **kwargs)
 
     def __getitem__(self, key):
@@ -374,13 +415,13 @@ class ReactionSystem(object):
                 if candidate is None:
                     candidate = r
                 else:
-                    raise ValueError('Multiple reactions with the same name')
+                    raise ValueError("Multiple reactions with the same name")
         if candidate is None:
             raise KeyError("No reaction with name %s found" % key)
         return candidate
 
     def subset(self, pred, checks=()):
-        """ Creates two new instances with the distinct subsets of reactions
+        """Creates two new instances with the distinct subsets of reactions
 
         First ReactionSystem will contain the reactions for which the predicate
         is True, the second for which it is False.
@@ -401,15 +442,22 @@ class ReactionSystem(object):
             yes.append(r) if pred(r) else no.append(r)
 
         def new_substances(coll):
-            return OrderedDict([(k, v) for k, v in self.substances.items() if
-                                any([k in r.keys() for r in coll])])
+            return OrderedDict(
+                [
+                    (k, v)
+                    for k, v in self.substances.items()
+                    if any([k in r.keys() for r in coll])
+                ]
+            )
 
-        return tuple(self.__class__(coll, substances=new_substances(coll), checks=checks)
-                     for coll in yes_no)
+        return tuple(
+            self.__class__(coll, substances=new_substances(coll), checks=checks)
+            for coll in yes_no
+        )
 
     @staticmethod
-    def concatenate(rsystems, cmp_attrs='reac inact_reac prod inact_prod'.split()):
-        """ Concatenates ReactionSystem instances
+    def concatenate(rsystems, cmp_attrs="reac inact_reac prod inact_prod".split()):
+        """Concatenates ReactionSystem instances
 
         Reactions with identical stoichiometries are added to a separated
         reactionsystem for "duplicates"
@@ -456,10 +504,12 @@ class ReactionSystem(object):
 
     def __add__(self, other):
         try:
-            substances = OrderedDict(chain(self.substances.items(), other.substances.items()))
+            substances = OrderedDict(
+                chain(self.substances.items(), other.substances.items())
+            )
         except AttributeError:
             substances = self.substances.copy()
-        other_rxns = list(getattr(other, 'rxns', other))
+        other_rxns = list(getattr(other, "rxns", other))
         if not all(isinstance(r, Reaction) for r in other_rxns):
             raise ValueError("Need an iterable of Reaction instances")
         return self.__class__(chain(self.rxns, other_rxns), substances, checks=())
@@ -470,11 +520,11 @@ class ReactionSystem(object):
         return self.rxns == other.rxns and self.substances == other.substances
 
     def substance_names(self):
-        """ Returns a tuple of the substances' names """
+        """Returns a tuple of the substances' names"""
         return tuple(substance.name for substance in self.substances.values())
 
     def substance_participation(self, substance_key):
-        r""" Returns indices of reactions where substance_key occurs
+        r"""Returns indices of reactions where substance_key occurs
 
         Parameters
         ----------
@@ -499,20 +549,22 @@ class ReactionSystem(object):
 
     @property
     def nr(self):
-        """ Number of reactions """
+        """Number of reactions"""
         return len(self.rxns)
 
     @property
     def ns(self):
-        """ Number of substances """
+        """Number of substances"""
         return len(self.substances)
 
     def params(self):
-        """ Returns list of per reaction ``param`` value """
+        """Returns list of per reaction ``param`` value"""
         return [rxn.param for rxn in self.rxns]
 
-    def as_per_substance_array(self, cont, dtype='float64', unit=None, raise_on_unk=False):
-        """ Turns a dict into an ordered array
+    def as_per_substance_array(
+        self, cont, dtype="float64", unit=None, raise_on_unk=False
+    ):
+        """Turns a dict into an ordered array
 
         Parameters
         ----------
@@ -523,6 +575,7 @@ class ReactionSystem(object):
 
         """
         import numpy as np
+
         if isinstance(cont, np.ndarray):
             pass
         elif isinstance(cont, dict):
@@ -538,20 +591,20 @@ class ReactionSystem(object):
         cont = np.atleast_1d(np.asarray(cont, dtype=dtype).squeeze())
         if cont.shape[-1] != self.ns:
             raise ValueError("Incorrect size")
-        return cont*(unit if unit is not None else 1)
+        return cont * (unit if unit is not None else 1)
 
     def as_per_substance_dict(self, arr):
         return dict(zip(self.substances.keys(), arr))
 
     def as_substance_index(self, substance_key):
-        """ Returns the index of a Substance in the system"""
+        """Returns the index of a Substance in the system"""
         if isinstance(substance_key, int):
             return substance_key
         else:
             return list(self.substances.keys()).index(substance_key)
 
     def per_substance_varied(self, per_substance, varied=None):
-        """ Dense nd-array for all combinations of varied levels per substance
+        """Dense nd-array for all combinations of varied levels per substance
 
         Parameters
         ----------
@@ -573,6 +626,7 @@ class ReactionSystem(object):
 
         """
         import numpy as np
+
         varied = varied or {}
         varied_keys = tuple(k for k in self.substances if k in varied)
         n_varied = len(varied)
@@ -583,20 +637,30 @@ class ReactionSystem(object):
             for k, vals in varied.items():
                 varied_axis = varied_keys.index(k)
                 for varied_idx, val in enumerate(vals):
-                    index = tuple(varied_idx if i == varied_axis else slice(None) for i in range(n_varied))
+                    index = tuple(
+                        varied_idx if i == varied_axis else slice(None)
+                        for i in range(n_varied)
+                    )
                     result[index + (self.as_substance_index(k),)] = val
         return result, varied_keys
 
     def per_reaction_effect_on_substance(self, substance_key):
         result = {}
         for ri, rxn in enumerate(self.rxns):
-            n, = rxn.net_stoich((substance_key,))
+            (n,) = rxn.net_stoich((substance_key,))
             if n != 0:
                 result[ri] = n
         return result
 
-    def rates(self, variables=None, backend=math, substance_keys=None, ratexs=None, cstr_fr_fc=None):
-        """ Per substance sums of reaction rates rates.
+    def rates(
+        self,
+        variables=None,
+        backend=math,
+        substance_keys=None,
+        ratexs=None,
+        cstr_fr_fc=None,
+    ):
+        """Per substance sums of reaction rates rates.
 
         Parameters
         ----------
@@ -625,9 +689,11 @@ class ReactionSystem(object):
         """
         result = {}
         if ratexs is None:
-            ratexs = [None]*self.nr
+            ratexs = [None] * self.nr
         for rxn, ratex in zip(self.rxns, ratexs):
-            for k, v in rxn.rate(variables, backend, substance_keys, ratex=ratex).items():
+            for k, v in rxn.rate(
+                variables, backend, substance_keys, ratex=ratex
+            ).items():
                 if k not in result:
                     result[k] = v
                 else:
@@ -635,43 +701,51 @@ class ReactionSystem(object):
         if cstr_fr_fc:
             fr_key, fc = cstr_fr_fc
             for sk, fck in fc.items():
-                result[sk] += variables[fr_key]*(variables[fck] - variables[sk])
+                result[sk] += variables[fr_key] * (variables[fck] - variables[sk])
         return result
 
     def _stoichs(self, attr, keys=None):
         import numpy as np
+
         if keys is None:
             keys = self.substances.keys()
         # dtype: see https://github.com/sympy/sympy/issues/10295
         return np.array([(getattr(eq, attr)(keys)) for eq in self.rxns], dtype=object)
 
     def net_stoichs(self, keys=None):
-        return self._stoichs('net_stoich', keys)
+        return self._stoichs("net_stoich", keys)
 
     def all_reac_stoichs(self, keys=None):
-        return self._stoichs('all_reac_stoich', keys)
+        return self._stoichs("all_reac_stoich", keys)
 
     def active_reac_stoichs(self, keys=None):
-        return self._stoichs('active_reac_stoich', keys)
+        return self._stoichs("active_reac_stoich", keys)
 
     def all_prod_stoichs(self, keys=None):
-        return self._stoichs('all_prod_stoich', keys)
+        return self._stoichs("all_prod_stoich", keys)
 
     def active_prod_stoichs(self, keys=None):
-        return self._stoichs('active_prod_stoich', keys)
+        return self._stoichs("active_prod_stoich", keys)
 
     def stoichs(self, non_precip_rids=()):  # TODO: rename to cond_stoichs
-        """ Conditional stoichiometries depending on precipitation status """
+        """Conditional stoichiometries depending on precipitation status"""
         # dtype: see https://github.com/sympy/sympy/issues/10295
         import numpy as np
-        return np.array([(
-            -np.array(eq.precipitate_stoich(self.substances)[0]) if idx
-            in non_precip_rids else
-            eq.non_precipitate_stoich(self.substances)
-        ) for idx, eq in enumerate(self.rxns)], dtype=object)
+
+        return np.array(
+            [
+                (
+                    -np.array(eq.precipitate_stoich(self.substances)[0])
+                    if idx in non_precip_rids
+                    else eq.non_precipitate_stoich(self.substances)
+                )
+                for idx, eq in enumerate(self.rxns)
+            ],
+            dtype=object,
+        )
 
     def composition_balance_vectors(self):
-        r""" Returns a list of lists with compositions and a list of composition keys.
+        r"""Returns a list of lists with compositions and a list of composition keys.
 
         The list of lists can be viewed as a matrix with rows corresponding to composition keys
         (which are given as the second item in the returned tuple) and columns corresponding to
@@ -698,7 +772,7 @@ class ReactionSystem(object):
         return [[s.composition.get(k, 0) for s in subs] for k in ck], ck
 
     def upper_conc_bounds(self, init_concs, min_=min, dtype=None, skip_keys=(0,)):
-        r""" Calculates upper concentration bounds per substance based on substance composition.
+        r"""Calculates upper concentration bounds per substance based on substance composition.
 
         Parameters
         ----------
@@ -732,6 +806,7 @@ class ReactionSystem(object):
 
         """
         import numpy as np
+
         if dtype is None:
             dtype = np.float64
         init_concs_arr = self.as_per_substance_array(init_concs, dtype=dtype)
@@ -740,22 +815,22 @@ class ReactionSystem(object):
             for comp_nr, coeff in s_obj.composition.items():
                 if comp_nr in skip_keys:  # charge may be created (if compensated)
                     continue
-                composition_conc[comp_nr] += coeff*conc
+                composition_conc[comp_nr] += coeff * conc
         bounds = []
         for s_obj in self.substances.values():
             choose_from = []
             for comp_nr, coeff in s_obj.composition.items():
                 if comp_nr == 0:
                     continue
-                choose_from.append(composition_conc[comp_nr]/coeff)
+                choose_from.append(composition_conc[comp_nr] / coeff)
             if len(choose_from) == 0:
-                bounds.append(float('inf'))
+                bounds.append(float("inf"))
             else:
                 bounds.append(min_(choose_from))
         return bounds
 
     def _unimolecular_reactions(self):
-        A = [None]*self.ns
+        A = [None] * self.ns
         unconsidered_ri = set()
         for i, r in enumerate(self.rxns):
             if r.order() == 1:
@@ -771,14 +846,18 @@ class ReactionSystem(object):
                 unconsidered_ri.add(i)
         return A, unconsidered_ri
 
-    @deprecated(last_supported_version='0.5.7', will_be_missing_in='0.8.0',
-                use_instead='chempy.printing.tables.UnimolecularTable')
+    @deprecated(
+        last_supported_version="0.5.7",
+        will_be_missing_in="0.8.0",
+        use_instead="chempy.printing.tables.UnimolecularTable",
+    )
     def unimolecular_html_table(self, *args, **kwargs):
         from .printing.tables import UnimolecularTable
+
         return UnimolecularTable.from_ReactionSystem(self)
 
     def _bimolecular_reactions(self):
-        A = [[None]*self.ns for _ in range(self.ns)]
+        A = [[None] * self.ns for _ in range(self.ns)]
         unconsidered_ri = set()
         for i, r in enumerate(self.rxns):
             if r.order() == 2:
@@ -796,23 +875,30 @@ class ReactionSystem(object):
                 unconsidered_ri.add(i)
         return A, unconsidered_ri
 
-    @deprecated(last_supported_version='0.5.7', will_be_missing_in='0.8.0',
-                use_instead='chempy.printing.tables.BimolecularTable')
+    @deprecated(
+        last_supported_version="0.5.7",
+        will_be_missing_in="0.8.0",
+        use_instead="chempy.printing.tables.BimolecularTable",
+    )
     def bimolecular_html_table(self, *args, **kwargs):
         from .printing.tables import BimolecularTable
+
         return BimolecularTable.from_ReactionSystem(self)
 
     def identify_equilibria(self):
-        """ Returns a list of index pairs of reactions forming equilibria.
+        """Returns a list of index pairs of reactions forming equilibria.
 
         The pairs are sorted with respect to index (lowest first)
         """
         eq = []
         for ri1, rxn1 in enumerate(self.rxns):
-            for ri2, rxn2 in enumerate(self.rxns[ri1+1:], ri1+1):
+            for ri2, rxn2 in enumerate(self.rxns[ri1 + 1 :], ri1 + 1):
 
-                all_eq = (rxn1.all_reac_stoich(self.substances) == rxn2.all_prod_stoich(self.substances) and
-                          rxn1.all_prod_stoich(self.substances) == rxn2.all_reac_stoich(self.substances))
+                all_eq = rxn1.all_reac_stoich(self.substances) == rxn2.all_prod_stoich(
+                    self.substances
+                ) and rxn1.all_prod_stoich(self.substances) == rxn2.all_reac_stoich(
+                    self.substances
+                )
                 if all_eq:
                     eq.append((ri1, ri2))
                     break
