@@ -15,7 +15,6 @@ rely on any attributes of the ``Quantity`` instances (and rather use
 getter & setter functions in `chempy.units`).
 
 """
-from __future__ import (absolute_import, division, print_function)
 
 from functools import reduce
 from operator import mul
@@ -25,7 +24,7 @@ import warnings
 from .util.arithmeticdict import ArithmeticDict
 from .util.pyutil import NameSpace, deprecated
 
-units_library = 'quantities'  # info used for selective testing.
+units_library = "quantities"  # info used for selective testing.
 
 
 try:
@@ -39,6 +38,7 @@ except ImportError:
 else:
     import numpy as np
     from .util._quantities import _patch_quantities
+
     _patch_quantities(pq)
     UncertainQuantity = pq.UncertainQuantity
     # Let us extend the underlying pq namespace with some common units in
@@ -47,64 +47,70 @@ else:
 
     default_units = NameSpace(pq)
     default_units.dm = default_units.decimetre = pq.UnitQuantity(
-        'decimetre',  default_units.m / 10.0, u_symbol='dm')
-    default_units.m3 = default_units.metre**3
-    default_units.dm3 = default_units.decimetre**3
-    default_units.cm3 = default_units.centimetre**3
-    if not hasattr(default_units, 'molar'):
+        "decimetre", default_units.m / 10.0, u_symbol="dm"
+    )
+    default_units.m3 = default_units.metre ** 3
+    default_units.dm3 = default_units.decimetre ** 3
+    default_units.cm3 = default_units.centimetre ** 3
+    if not hasattr(default_units, "molar"):
         default_units.molar = pq.UnitQuantity(
-            'M',  1e3 * default_units.mole/default_units.m3,
-            u_symbol='M')
-    if not hasattr(default_units, 'millimolar'):
+            "M", 1e3 * default_units.mole / default_units.m3, u_symbol="M"
+        )
+    if not hasattr(default_units, "millimolar"):
         default_units.millimolar = pq.UnitQuantity(
-            'mM', 1 * default_units.mole/default_units.m3,
-            u_symbol='mM')
-    if not hasattr(default_units, 'micromolar'):
+            "mM", 1 * default_units.mole / default_units.m3, u_symbol="mM"
+        )
+    if not hasattr(default_units, "micromolar"):
         default_units.micromolar = pq.UnitQuantity(
-            'uM',  1e-3 * default_units.mole/default_units.m3,
-            u_symbol='μM')
-    if not hasattr(default_units, 'nanomolar'):
+            "uM", 1e-3 * default_units.mole / default_units.m3, u_symbol="μM"
+        )
+    if not hasattr(default_units, "nanomolar"):
         default_units.nanomolar = pq.UnitQuantity(
-            'nM', 1e-6 * default_units.mole/default_units.m3,
-            u_symbol='nM')
-    if not hasattr(default_units, 'molal'):
+            "nM", 1e-6 * default_units.mole / default_units.m3, u_symbol="nM"
+        )
+    if not hasattr(default_units, "molal"):
         default_units.molal = pq.UnitQuantity(
-            'molal',  default_units.mole / default_units.kg,
-            u_symbol='molal')
-    if not hasattr(default_units, 'per100eV'):
+            "molal", default_units.mole / default_units.kg, u_symbol="molal"
+        )
+    if not hasattr(default_units, "per100eV"):
         default_units.per100eV = pq.UnitQuantity(
-            'per_100_eV',
-            1/(100*default_units.eV*default_constants.Avogadro_constant),
-            u_symbol='(100eV)**-1')
-    if not hasattr(default_units, 'micromole'):
+            "per_100_eV",
+            1 / (100 * default_units.eV * default_constants.Avogadro_constant),
+            u_symbol="(100eV)**-1",
+        )
+    if not hasattr(default_units, "micromole"):
         default_units.micromole = pq.UnitQuantity(
-            'micromole',  pq.mole/1e6,  u_symbol=u'μmol')
-    if not hasattr(default_units, 'nanomole'):
+            "micromole", pq.mole / 1e6, u_symbol="μmol"
+        )
+    if not hasattr(default_units, "nanomole"):
         default_units.nanomole = pq.UnitQuantity(
-            'nanomole',  pq.mole/1e9,  u_symbol=u'nmol')
-    if not hasattr(default_units, 'kilojoule'):
+            "nanomole", pq.mole / 1e9, u_symbol="nmol"
+        )
+    if not hasattr(default_units, "kilojoule"):
         default_units.kilojoule = pq.UnitQuantity(
-            'kilojoule',  1e3*pq.joule,  u_symbol='kJ')
-    if not hasattr(default_units, 'kilogray'):
+            "kilojoule", 1e3 * pq.joule, u_symbol="kJ"
+        )
+    if not hasattr(default_units, "kilogray"):
         default_units.kilogray = pq.UnitQuantity(
-            'kilogray',  1e3*pq.gray,  u_symbol='kGy')
-    if not hasattr(default_units, 'perMolar_perSecond'):
-        default_units.perMolar_perSecond = 1/default_units.molar/pq.s
-    if not hasattr(default_units, 'umol'):
+            "kilogray", 1e3 * pq.gray, u_symbol="kGy"
+        )
+    if not hasattr(default_units, "perMolar_perSecond"):
+        default_units.perMolar_perSecond = 1 / default_units.molar / pq.s
+    if not hasattr(default_units, "umol"):
         default_units.umol = default_units.micromole
-    if not hasattr(default_units, 'umol_per_J'):
+    if not hasattr(default_units, "umol_per_J"):
         default_units.umol_per_J = default_units.umol / pq.joule
 
     # unit registry data and logic:
 
     SI_base_registry = {
-        'length': default_units.metre,
-        'mass': default_units.kilogram,
-        'time': default_units.second,
-        'current': default_units.ampere,
-        'temperature': default_units.kelvin,
-        'luminous_intensity': default_units.candela,
-        'amount': default_units.mole
+        "length": default_units.metre,
+        "mass": default_units.kilogram,
+        "time": default_units.second,
+        "current": default_units.ampere,
+        "temperature": default_units.kelvin,
+        "luminous_intensity": default_units.candela,
+        "amount": default_units.mole,
     }
 
 
@@ -123,34 +129,35 @@ def uncertainty(uval):
 
 
 def simplified(value):
-    if hasattr(value, 'simplified'):
+    if hasattr(value, "simplified"):
         return value.simplified
     else:
         return to_unitless(value)
 
 
 def is_quantity(arg):
-    if arg.__class__.__name__ == 'Quantity':
+    if arg.__class__.__name__ == "Quantity":
         return True  # this checks works even if quantities is not installed.
     else:
         return False
 
+
 # SI Base Quantities:
-time = ArithmeticDict(int, {'time': 1})
-length = ArithmeticDict(int, {'length': 1})
-mass = ArithmeticDict(int, {'mass': 1})
-current = ArithmeticDict(int, {'current': 1})
-temperature = ArithmeticDict(int, {'temperature': 1})
-amount = ArithmeticDict(int, {'amount': 1})
+time = ArithmeticDict(int, {"time": 1})
+length = ArithmeticDict(int, {"length": 1})
+mass = ArithmeticDict(int, {"mass": 1})
+current = ArithmeticDict(int, {"current": 1})
+temperature = ArithmeticDict(int, {"temperature": 1})
+amount = ArithmeticDict(int, {"amount": 1})
 # intensity = ArithmeticDict(int, {'intensity': 1}) what's wrong with photon flux? (human eyes, bah!)
 
-energy = ArithmeticDict(int, {'mass': 1, 'length': 2, 'time': -2})
-volume = ArithmeticDict(int, {'length': 3})
-concentration = {'amount': 1} - volume
+energy = ArithmeticDict(int, {"mass": 1, "length": 2, "time": -2})
+volume = ArithmeticDict(int, {"length": 3})
+concentration = {"amount": 1} - volume
 
 
 def get_derived_unit(registry, key):
-    """ Get the unit of a physcial quantity in a provided unit system.
+    """Get the unit of a physcial quantity in a provided unit system.
 
     Parameters
     ----------
@@ -173,20 +180,24 @@ def get_derived_unit(registry, key):
     if registry is None:
         return 1.0
     derived = {
-        'diffusivity': registry['length']**2/registry['time'],
-        'electrical_mobility': (registry['current']*registry['time']**2 /
-                                registry['mass']),
-        'permittivity': (registry['current']**2*registry['time']**4 /
-                         (registry['length']**3*registry['mass'])),
-        'charge': registry['current']*registry['time'],
-        'energy': registry['mass']*registry['length']**2/registry['time']**2,
-        'concentration': registry['amount']/registry['length']**3,
-        'density': registry['mass']/registry['length']**3,
+        "diffusivity": registry["length"] ** 2 / registry["time"],
+        "electrical_mobility": (
+            registry["current"] * registry["time"] ** 2 / registry["mass"]
+        ),
+        "permittivity": (
+            registry["current"] ** 2
+            * registry["time"] ** 4
+            / (registry["length"] ** 3 * registry["mass"])
+        ),
+        "charge": registry["current"] * registry["time"],
+        "energy": registry["mass"] * registry["length"] ** 2 / registry["time"] ** 2,
+        "concentration": registry["amount"] / registry["length"] ** 3,
+        "density": registry["mass"] / registry["length"] ** 3,
     }
-    derived['diffusion'] = derived['diffusivity']  # 'diffusion' is deprecated
-    derived['radiolytic_yield'] = registry['amount']/derived['energy']
-    derived['doserate'] = derived['energy']/registry['mass']/registry['time']
-    derived['linear_energy_transfer'] = derived['energy']/registry['length']
+    derived["diffusion"] = derived["diffusivity"]  # 'diffusion' is deprecated
+    derived["radiolytic_yield"] = registry["amount"] / derived["energy"]
+    derived["doserate"] = derived["energy"] / registry["mass"] / registry["time"]
+    derived["linear_energy_transfer"] = derived["energy"] / registry["length"]
 
     try:
         return derived[key]
@@ -195,7 +206,7 @@ def get_derived_unit(registry, key):
 
 
 def unit_registry_to_human_readable(unit_registry):
-    """ Serialization of a unit registry. """
+    """Serialization of a unit registry."""
     if unit_registry is None:
         return None
     new_registry = {}
@@ -206,8 +217,7 @@ def unit_registry_to_human_readable(unit_registry):
         else:
             dim_list = list(unit_registry[k].dimensionality)
             if len(dim_list) != 1:
-                raise TypeError("Compound units not allowed: {}".format(
-                    dim_list))
+                raise TypeError("Compound units not allowed: {}".format(dim_list))
             u_symbol = dim_list[0].u_symbol
             new_registry[k] = float(unit_registry[k]), u_symbol
     return new_registry
@@ -216,11 +226,12 @@ def unit_registry_to_human_readable(unit_registry):
 def _latex_from_dimensionality(dim):
     # see https://github.com/python-quantities/python-quantities/issues/148
     from quantities.markup import format_units_latex
-    return format_units_latex(dim, mult=r'\\cdot')
+
+    return format_units_latex(dim, mult=r"\\cdot")
 
 
 def latex_of_unit(quant):
-    """ Returns LaTeX reperesentation of the unit of a quantity
+    """Returns LaTeX reperesentation of the unit of a quantity
 
     Examples
     --------
@@ -228,11 +239,11 @@ def latex_of_unit(quant):
     \\mathrm{\\frac{1}{K}}
 
     """
-    return _latex_from_dimensionality(quant.dimensionality).strip('$')
+    return _latex_from_dimensionality(quant.dimensionality).strip("$")
 
 
 def unicode_of_unit(quant):
-    """ Returns unicode reperesentation of the unit of a quantity
+    """Returns unicode reperesentation of the unit of a quantity
 
     Examples
     --------
@@ -244,7 +255,7 @@ def unicode_of_unit(quant):
 
 
 def html_of_unit(quant):
-    """ Returns HTML reperesentation of the unit of a quantity
+    """Returns HTML reperesentation of the unit of a quantity
 
     Examples
     --------
@@ -256,7 +267,7 @@ def html_of_unit(quant):
 
 
 def unit_registry_from_human_readable(unit_registry):
-    """ Deserialization of unit_registry. """
+    """Deserialization of unit_registry."""
     if unit_registry is None:
         return None
     new_registry = {}
@@ -270,14 +281,15 @@ def unit_registry_from_human_readable(unit_registry):
         if len(unit_quants) != 1:
             raise TypeError("Unkown UnitQuantity: {}".format(unit_registry[k]))
         else:
-            new_registry[k] = factor*unit_quants[0]
+            new_registry[k] = factor * unit_quants[0]
     return new_registry
 
 
 # Abstraction of underlying package providing units and dimensional analysis:
 
+
 def is_unitless(expr):
-    """ Returns ``True`` if ``expr`` is unitless, otherwise ``False``
+    """Returns ``True`` if ``expr`` is unitless, otherwise ``False``
 
     Examples
     --------
@@ -287,7 +299,7 @@ def is_unitless(expr):
     False
 
     """
-    if hasattr(expr, 'dimensionality'):
+    if hasattr(expr, "dimensionality"):
         if expr.dimensionality == pq.dimensionless:
             return True
         else:
@@ -300,7 +312,7 @@ def is_unitless(expr):
 
 
 def unit_of(expr, simplified=False):
-    """ Returns the unit of a quantity
+    """Returns the unit of a quantity
 
     Examples
     --------
@@ -335,7 +347,7 @@ def rescale(value, unit):
 
 
 def to_unitless(value, new_unit=None):
-    """ Nondimensionalization of a quantity.
+    """Nondimensionalization of a quantity.
 
     Parameters
     ----------
@@ -356,7 +368,7 @@ def to_unitless(value, new_unit=None):
 
     if isinstance(value, (list, tuple)):
         return np.array([to_unitless(elem, new_unit) for elem in value])
-    elif isinstance(value, np.ndarray) and not hasattr(value, 'rescale'):
+    elif isinstance(value, np.ndarray) and not hasattr(value, "rescale"):
         if is_unitless(new_unit) and new_unit == 1 and value.dtype != object:
             return value
         return np.array([to_unitless(elem, new_unit) for elem in value])
@@ -365,14 +377,16 @@ def to_unitless(value, new_unit=None):
         for k in value:
             new_value[k] = to_unitless(value[k], new_unit)
         return new_value
-    elif isinstance(value, (int, float)) and new_unit is integer_one or new_unit is None:
+    elif (
+        isinstance(value, (int, float)) and new_unit is integer_one or new_unit is None
+    ):
         return value
     elif isinstance(value, str):
         raise ValueError("str not supported")
     else:
         try:
             try:
-                result = (value*pq.dimensionless/new_unit).rescale(pq.dimensionless)
+                result = (value * pq.dimensionless / new_unit).rescale(pq.dimensionless)
             except AttributeError:
                 if new_unit == pq.dimensionless:
                     return value
@@ -388,7 +402,7 @@ def to_unitless(value, new_unit=None):
 
 
 def uniform(container):
-    """ Turns a list, tuple or dict with mixed units into one with uniform units.
+    """Turns a list, tuple or dict with mixed units into one with uniform units.
 
     Parameters
     ----------
@@ -405,35 +419,39 @@ def uniform(container):
         unit = unit_of(container[0])
     elif isinstance(container, dict):
         unit = unit_of(list(container.values())[0])
-        return container.__class__([(k, to_unitless(v, unit)*unit) for k, v in container.items()])
+        return container.__class__(
+            [(k, to_unitless(v, unit) * unit) for k, v in container.items()]
+        )
     else:
         return container
-    return to_unitless(container, unit)*unit
+    return to_unitless(container, unit) * unit
 
 
 def get_physical_dimensionality(value):
     if is_unitless(value):
         return {}
     _quantities_mapping = {
-        pq.UnitLength: 'length',
-        pq.UnitMass: 'mass',
-        pq.UnitTime: 'time',
-        pq.UnitCurrent: 'current',
-        pq.UnitTemperature: 'temperature',
-        pq.UnitLuminousIntensity: 'luminous_intensity',
-        pq.UnitSubstance: 'amount'
+        pq.UnitLength: "length",
+        pq.UnitMass: "mass",
+        pq.UnitTime: "time",
+        pq.UnitCurrent: "current",
+        pq.UnitTemperature: "temperature",
+        pq.UnitLuminousIntensity: "luminous_intensity",
+        pq.UnitSubstance: "amount",
+    }
+    return {
+        _quantities_mapping[k.__class__]: v
+        for k, v in uniform(value).simplified.dimensionality.items()
     }
-    return {_quantities_mapping[k.__class__]: v for k, v
-            in uniform(value).simplified.dimensionality.items()}
 
 
-@deprecated(use_instead=get_physical_dimensionality, will_be_missing_in='0.8.0')
+@deprecated(use_instead=get_physical_dimensionality, will_be_missing_in="0.8.0")
 def get_physical_quantity(value):
     return get_physical_dimensionality(value)
 
 
 def _get_unit_from_registry(dimensionality, registry):
-    return reduce(mul, [registry[k]**v for k, v in dimensionality.items()])
+    return reduce(mul, [registry[k] ** v for k, v in dimensionality.items()])
 
 
 def default_unit_in_registry(value, registry):
@@ -450,8 +468,9 @@ def unitless_in_registry(value, registry):
 
 # NumPy like functions for compatibility:
 
+
 def compare_equality(a, b):
-    """ Returns True if two arguments are equal.
+    """Returns True if two arguments are equal.
 
     Both arguments need to have the same dimensionality.
 
@@ -490,7 +509,7 @@ def compare_equality(a, b):
 
 
 def allclose(a, b, rtol=1e-8, atol=None):
-    """ Analogous to ``numpy.allclose``. """
+    """Analogous to ``numpy.allclose``."""
     if a.__class__.__name__ == "UncertainQuantity":
         return allclose(pq.Quantity(a), b, rtol=rtol, atol=atol)
     if b.__class__.__name__ == "UncertainQuantity":
@@ -506,7 +525,7 @@ def allclose(a, b, rtol=1e-8, atol=None):
                 return False
         except Exception:
             return False
-    lim = abs(a)*rtol
+    lim = abs(a) * rtol
     if atol is not None:
         lim += atol
 
@@ -524,7 +543,7 @@ def allclose(a, b, rtol=1e-8, atol=None):
 
 
 def linspace(start, stop, num=50):
-    """ Analogous to ``numpy.linspace``.
+    """Analogous to ``numpy.linspace``.
 
     Examples
     --------
@@ -537,11 +556,11 @@ def linspace(start, stop, num=50):
     unit = unit_of(start)
     start_ = to_unitless(start, unit)
     stop_ = to_unitless(stop, unit)
-    return np.linspace(start_, stop_, num)*unit
+    return np.linspace(start_, stop_, num) * unit
 
 
 def logspace_from_lin(start, stop, num=50):
-    """ Logarithmically spaced data points
+    """Logarithmically spaced data points
 
     Examples
     --------
@@ -552,7 +571,7 @@ def logspace_from_lin(start, stop, num=50):
     unit = unit_of(start)
     start_ = np.log2(to_unitless(start, unit))
     stop_ = np.log2(to_unitless(stop, unit))
-    return np.exp2(np.linspace(start_, stop_, num))*unit
+    return np.exp2(np.linspace(start_, stop_, num)) * unit
 
 
 def _sum(iterable):
@@ -574,7 +593,7 @@ def _sum(iterable):
 
 
 class Backend(object):
-    """ Wrapper around modules such as numpy and math
+    """Wrapper around modules such as numpy and math
 
     Instances of Backend wraps a module, e.g. `numpy` and ensures that
     arguments passed on are unitless, i.e. it raises an error if a
@@ -605,7 +624,7 @@ class Backend(object):
 
     """
 
-    def __init__(self, underlying_backend=('numpy', 'math')):
+    def __init__(self, underlying_backend=("numpy", "math")):
         if isinstance(underlying_backend, tuple):
             for name in underlying_backend:
                 try:
@@ -615,8 +634,7 @@ class Backend(object):
                 else:
                     break
             else:
-                raise ValueError("Could not import any of %s" %
-                                 str(underlying_backend))
+                raise ValueError("Could not import any of %s" % str(underlying_backend))
         elif isinstance(underlying_backend, str):
             self.be = __import__(underlying_backend)
         else:
@@ -631,8 +649,8 @@ class Backend(object):
 
 
 # TODO: decide whether to deprecate in favor of "number_to_scientific_latex"?
-def format_string(value, precision='%.5g', tex=False):
-    """ Formats a scalar with unit as two strings
+def format_string(value, precision="%.5g", tex=False):
+    """Formats a scalar with unit as two strings
 
     Parameters
     ----------
@@ -653,13 +671,14 @@ def format_string(value, precision='%.5g', tex=False):
         unit_str = latex_of_unit(value)
     else:
         from quantities.markup import config
-        attr = 'unicode' if config.use_unicode else 'string'
+
+        attr = "unicode" if config.use_unicode else "string"
         unit_str = getattr(value.dimensionality, attr)
     return precision % float(value.magnitude), unit_str
 
 
 def concatenate(arrays, **kwargs):
-    """ Patched version of numpy.concatenate
+    """Patched version of numpy.concatenate
 
     Examples
     --------
@@ -670,11 +689,11 @@ def concatenate(arrays, **kwargs):
     """
     unit = unit_of(arrays[0])
     result = np.concatenate([to_unitless(arr, unit) for arr in arrays], **kwargs)
-    return result*unit
+    return result * unit
 
 
 def tile(array, *args, **kwargs):
-    """ Patched version of numpy.tile (with support for units) """
+    """Patched version of numpy.tile (with support for units)"""
     try:
         elem = array[0, ...]
     except TypeError:
@@ -682,7 +701,7 @@ def tile(array, *args, **kwargs):
 
     unit = unit_of(elem)
     result = np.tile(to_unitless(array, unit), *args, **kwargs)
-    return result*unit
+    return result * unit
 
 
 def polyfit(x, y, deg, **kwargs):
@@ -690,7 +709,7 @@ def polyfit(x, y, deg, **kwargs):
     u_y = unit_of(y[0])
     _x, _y = to_unitless(x, u_x), to_unitless(y, u_y)
     p = np.polyfit(_x, _y, deg)
-    return [v*u_y*u_x**(i-deg) for i, v in enumerate(p)]
+    return [v * u_y * u_x ** (i - deg) for i, v in enumerate(p)]
 
 
 def polyval(p, x):
@@ -700,10 +719,10 @@ def polyval(p, x):
         u_x = unit_of(x)
     u_y = unit_of(p[-1])
     deg = len(p) - 1
-    _p = [to_unitless(v, u_y*u_x**(i-deg)) for i, v in enumerate(p)]
+    _p = [to_unitless(v, u_y * u_x ** (i - deg)) for i, v in enumerate(p)]
     _x = to_unitless(x, u_x)
     _y = np.polyval(_p, _x)
-    return _y*u_y
+    return _y * u_y
 
 
 def _wrap_numpy(k):
@@ -711,14 +730,17 @@ def _wrap_numpy(k):
     if sys.version_info[0] > 2:
         from functools import wraps
     else:
+
         def wraps(_meta_fun):
             return lambda x: x  # py2: numpy.ufunc lacks "__module__"
 
     @wraps(numpy_func)
     def f(*args, **kwargs):
         return numpy_func(*map(to_unitless, args), **kwargs)
+
     return f
 
+
 if np is None:
     patched_numpy = None
 else:
@@ -729,19 +751,19 @@ else:
     patched_numpy.tile = tile
     patched_numpy.polyfit = polyfit
     patched_numpy.polyval = polyval
-    for k in 'log log10 log2 log1p exp expm1 logaddexp logaddexp2'.split():
+    for k in "log log10 log2 log1p exp expm1 logaddexp logaddexp2".split():
         setattr(patched_numpy, k, _wrap_numpy(k))
 
 
 def fold_constants(arg):
-    if hasattr(arg, 'dimensionality'):
+    if hasattr(arg, "dimensionality"):
         m = arg.magnitude
         d = 1
         for k, v in arg.dimensionality.items():
             if isinstance(k, pq.UnitConstant):
-                m = m * k.simplified**v
+                m = m * k.simplified ** v
             else:
-                d = d * k**v
-        return m*d
+                d = d * k ** v
+        return m * d
     else:
         return arg
